
ShimmerCat's tool
=================

This is a helper tool that simplifies working with ShimmerCat. It is written in pure Python.



See https://www.shimmercat.com/info/articles/getting-started/ for  a longer explanation of how to use this tool.